package jalview.ws.rest.params;

import jalview.datamodel.AlignmentI;
import jalview.datamodel.SequenceI;
import jalview.ws.rest.InputType;
import jalview.ws.rest.NoValidInputDataException;
import jalview.ws.rest.RestJob;
import jalview.ws.rest.RestServiceDescription;
import jalview.ws.rest.InputType.molType;

import java.io.UnsupportedEncodingException;
import java.util.ArrayList;
import java.util.List;

import org.apache.http.entity.mime.content.ContentBody;
import org.apache.http.entity.mime.content.StringBody;

/**
 * input a list of sequences separated by some separator 
 * @author JimP
 *
 */
public class SeqVector extends InputType {
  String sep;
  molType type;
  public SeqVector()
  {
    super(new Class[] { AlignmentI.class} );
  }

  @Override
  public ContentBody formatForInput(RestJob rj) throws UnsupportedEncodingException, NoValidInputDataException
  {
    StringBuffer idvector = new StringBuffer();
    boolean list=false;
    for (SequenceI seq:rj.getSequencesForInput(token, type))
    {
      if (list)
      {
        idvector.append(sep);
      }
      idvector.append(seq.getSequence());
    }
    return new StringBody(idvector.toString());
  }
  @Override
  public List<String> getURLEncodedParameter()
  {
    ArrayList<String> prms = new ArrayList<String>();
    super.addBaseParams(prms);
    prms.add("sep='"+ sep+"'");
    prms.add("type='"+type+"'");
    return prms;
  }

  @Override
  public String getURLtokenPrefix()
  {
    return "SEQS";
  }

  @Override
  public boolean configureProperty(String tok, String val,
          StringBuffer warnings)
  {

    if (tok.startsWith("sep"))
    {
      sep=val;
      return true;
    }
    if (tok.startsWith("type"))
    {
      try {
        type=molType.valueOf(val);
        return true;
      } catch (Exception x)
      {
        warnings.append("Invalid molecule type '"+val+"'. Must be one of (");
        for (molType v:molType.values())
        {
          warnings.append(" "+v);
        }
        warnings.append(")\n");
      }
    }
    return false;
  }

}